Model subclass: #Node
	instanceVariableNames: 'name nextNode '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'demo-LAN'!
Node comment:
'I represent a basic node in the LAN framework, with a name and a next node. I can receive packets with the accept: method, and send them to my nextnode with the send: method.



Instance Variables:

	name: my name

	nextNode: the next node I point to.'!


!Node methodsFor: 'initialize-release'!

initialize

	"I am the default initialize method. My subclasses might want to override me to do something usefull"! !

!Node methodsFor: 'sending/receiving'!

accept: thePacket
	"Having received the packet, send it on. This is the default behavior"
	"My subclasses will probably override me to do something special"

	self send: thePacket!

send: thePacket
	"Display debug information in the Transcript, then send the packet to the node with whom I communicate"

	Transcript show: self name printString,' sending the packet to ',self nextNode name printString;cr.
	self nextNode accept: thePacket! !

!Node methodsFor: 'printing'!

printOn: aStream
	"I add a textual representation of myself on my argument, aStream"

	super printOn: aStream.
	aStream nextPutAll: ' with name:'; print: self name.
	self nextNode isNil ifFalse: [aStream nextPutAll: ' and next node:'; print: self nextNode name]! !

!Node methodsFor: 'accessing'!

name

	^name!

name: aSymbol

	name := aSymbol!

nextNode

	^nextNode!

nextNode: aNode

	nextNode := aNode! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

Node class
	instanceVariableNames: ''!


!Node class methodsFor: 'instance creation'!

new

	"I create and return a new initialized instance"



	^super new initialize! !

Node subclass: #FileServer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'demo-LAN'!


!FileServer methodsFor: 'sending/receiving'!

accept: thePacket

	"If the packet is addressed to me, I save it. Otherwise I let my superclass handle it"



	(self name = thePacket addressee)

		ifTrue: [self save: thePacket]

		ifFalse: [super accept: thePacket]! !

!FileServer methodsFor: 'saving'!

save: thePacket

	"I have to save the packet. Write this on the transcript"



	Transcript show: 'fileserver ',self name printString,' saving the packet with contents: ',thePacket contents printString! !

Node subclass: #Workstation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'demo-LAN'!


!Workstation methodsFor: 'sending/receiving'!

accept: thePacket

	(thePacket originator = self)
		ifTrue: [Transcript show: 'Packet taken out because of invalid addressee (',thePacket addressee printString,')']
		ifFalse: [super accept: thePacket]! !

!Workstation methodsFor: 'originating'!

originate: thePacket
	"This is how packets get inserted into the network. 
	This is a likely method to be rewritten to permit packets to be entered in various ways. 
	Currently, I assume that someone else creates the packet and passes it to me as an argument."

	thePacket originator: self.
	self send: thePacket! !

Object subclass: #Packet
	instanceVariableNames: 'contents addressee originator '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'demo-LAN'!


!Packet methodsFor: 'printing'!

printOn: aStream

	super printOn: aStream.
	aStream nextPutAll: ' addressed to: '; print: self addressee.
	aStream nextPutAll: ' with contents:'; print: self contents! !

!Packet methodsFor: 'accessing'!

addressee

	^addressee!

addressee: aSymbol

	addressee := aSymbol!

contents

	^contents!

contents: aString

	contents := aString!

originator

	^originator!

originator: aNode

	originator := aNode! !

Node subclass: #PrintServer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'demo-LAN'!


!PrintServer methodsFor: 'printing'!

print: thePacket
	"I have to print the packet. Write this on the transcript"

	Transcript show: 'printer ',self name printString,' printing the packet with contents: ',thePacket contents printString! !

!PrintServer methodsFor: 'sending/receiving'!

accept: thePacket
	"If the packet is addressed to me, I print it. Otherwise I let my superclass handle it"

	(self name = thePacket addressee)
		ifTrue: [self print: thePacket]
		ifFalse: [super accept: thePacket]! !

